pango/pango64.patch

53 lines
1.8 KiB
Diff

--- modules/Makefile.am
+++ modules/Makefile.am
@@ -30,10 +30,10 @@
@if $(RUN_QUERY_MODULES_TEST) ; then \
echo $(mkinstalldirs) $(DESTDIR)$(sysconfdir)/pango \&\& \
$(top_builddir)/pango/pango-querymodules \
- \> $(DESTDIR)$(sysconfdir)/pango/pango.modules ; \
+ \> $(DESTDIR)$(sysconfdir)/pango/pango64.modules ; \
$(mkinstalldirs) $(DESTDIR)$(sysconfdir)/pango && \
$(top_builddir)/pango/pango-querymodules \
- > $(DESTDIR)$(sysconfdir)/pango/pango.modules ; \
+ > $(DESTDIR)$(sysconfdir)/pango/pango64.modules ; \
else \
echo "***" ; \
echo "*** Warning: $(sysconfdir)/pango/pango.modules" ; \
--- modules/pangorc
+++ modules/pangorc
@@ -5,4 +5,4 @@
#
[Pango]
-ModuleFiles = ../modules/pango.modules
+ModuleFiles = ../modules/pango64.modules
--- pango/modules.c
+++ pango/modules.c
@@ -309,7 +309,7 @@
/* This is an entry put there by make install on the
* packager's system. On Windows a prebuilt Pango
* package can be installed in a random
* location. The pango.modules file distributed in
* such a package contains paths from the package
* builder's machine. Replace the path with the real
* one on this machine. */
@@ -489,7 +489,7 @@
if (!file_str)
file_str = g_build_filename (pango_get_sysconf_subdirectory (),
- "pango.modules",
+ "pango64.modules",
NULL);
files = pango_split_file_list (file_str);
@@ -597,7 +597,7 @@
if (!no_module_warning)
{
gchar *filename = g_build_filename (pango_get_sysconf_subdirectory (),
- "pango.modules",
+ "pango64.modules",
NULL);
g_warning ("No builtin or dynamically\n"
"loaded modules were found. Pango will not work correctly.\n"
@@ -309,7 +309,7 @@
* packager's system. On Windows a prebuilt Pango
* package can be installed in a random
- * location. The pango.modules file distributed in
+ * location. The pango64.modules file distributed in
* such a package contains paths from the package
* builder's machine. Replace the path with the real